Function run_suite
pub async fn run_suite(dir: &Path, mode: Mode) -> Result<SuiteReport>Expand description
Run every *.json trace fixture in dir and return an aggregated report.
pub async fn run_suite(dir: &Path, mode: Mode) -> Result<SuiteReport>Run every *.json trace fixture in dir and return an aggregated report.